[llvm-commits] CVS: llvm/lib/Transforms/Scalar/ConstantProp.cpp CorrelatedExprs.cpp SCCP.cpp

Michael Brukman brukman at cs.uiuc.edu
Tue May 20 16:02:04 PDT 2003


Changes in directory llvm/lib/Transforms/Scalar:

ConstantProp.cpp updated: 1.40 -> 1.41
CorrelatedExprs.cpp updated: 1.9 -> 1.10
SCCP.cpp updated: 1.68 -> 1.69

---
Log message:

Hopefully, the final fix for `[Pp]ropogate'.


---
Diffs of the changes:

Index: llvm/lib/Transforms/Scalar/CorrelatedExprs.cpp
diff -u llvm/lib/Transforms/Scalar/CorrelatedExprs.cpp:1.9 llvm/lib/Transforms/Scalar/CorrelatedExprs.cpp:1.10
--- llvm/lib/Transforms/Scalar/CorrelatedExprs.cpp:1.9	Wed Apr 23 11:37:42 2003
+++ llvm/lib/Transforms/Scalar/CorrelatedExprs.cpp	Tue May 20 16:01:16 2003
@@ -300,7 +300,7 @@
 // TransformRegion - Transform the region starting with BB according to the
 // calculated region information for the block.  Transforming the region
 // involves analyzing any information this block provides to successors,
-// propogating the information to successors, and finally transforming
+// propagating the information to successors, and finally transforming
 // successors.
 //
 // This method processes the function in depth first order, which guarantees
@@ -885,7 +885,7 @@
     return;
 
   // If we already have information that contradicts the current information we
-  // are propogating, ignore this info.  Something bad must have happened!
+  // are propagating, ignore this info.  Something bad must have happened!
   //
   if (Op1R.contradicts(Opcode, VI)) {
     Op1R.contradicts(Opcode, VI);


Index: llvm/lib/Transforms/Scalar/SCCP.cpp
diff -u llvm/lib/Transforms/Scalar/SCCP.cpp:1.68 llvm/lib/Transforms/Scalar/SCCP.cpp:1.69
--- llvm/lib/Transforms/Scalar/SCCP.cpp:1.68	Wed May  7 21:50:13 2003
+++ llvm/lib/Transforms/Scalar/SCCP.cpp	Tue May 20 16:01:16 2003
@@ -1,6 +1,6 @@
-//===- SCCP.cpp - Sparse Conditional Constant Propogation -----------------===//
+//===- SCCP.cpp - Sparse Conditional Constant Propagation -----------------===//
 //
-// This file implements sparse conditional constant propogation and merging:
+// This file implements sparse conditional constant propagation and merging:
 //
 // Specifically, this:
 //   * Assumes values are constant unless proven otherwise
@@ -75,7 +75,7 @@
 //===----------------------------------------------------------------------===//
 // SCCP Class
 //
-// This class does all of the work of Sparse Conditional Constant Propogation.
+// This class does all of the work of Sparse Conditional Constant Propagation.
 //
 namespace {
 class SCCP : public FunctionPass, public InstVisitor<SCCP> {
@@ -86,7 +86,7 @@
   std::vector<BasicBlock*>  BBWorkList;  // The BasicBlock work list
 public:
 
-  // runOnFunction - Run the Sparse Conditional Constant Propogation algorithm,
+  // runOnFunction - Run the Sparse Conditional Constant Propagation algorithm,
   // and return true if the function was modified.
   //
   bool runOnFunction(Function &F);
@@ -239,7 +239,7 @@
 // SCCP Class Implementation
 
 
-// runOnFunction() - Run the Sparse Conditional Constant Propogation algorithm,
+// runOnFunction() - Run the Sparse Conditional Constant Propagation algorithm,
 // and return true if the function was modified.
 //
 bool SCCP::runOnFunction(Function &F) {





More information about the llvm-commits mailing list
Index: llvm/lib/Transforms/Scalar/ConstantProp.cpp
diff -u llvm/lib/Transforms/Scalar/ConstantProp.cpp:1.40 llvm/lib/Transforms/Scalar/ConstantProp.cpp:1.41
--- llvm/lib/Transforms/Scalar/ConstantProp.cpp:1.40	Mon Oct 21 15:00:26 2002
+++ llvm/lib/Transforms/Scalar/ConstantProp.cpp	Tue May 20 16:01:16 2003
@@ -1,6 +1,6 @@
 //===- ConstantProp.cpp - Code to perform Simple Constant Propogation -----===//
 //
 // This file implements constant propogation and merging:
 //
 // Specifically, this:
 //   * Converts instructions like "add int 1, 2" into 3
@@ -23,7 +23,7 @@
 namespace {
   Statistic<> NumInstKilled("constprop", "Number of instructions killed");
 
-  struct ConstantPropogation : public FunctionPass {
+  struct ConstantPropagation : public FunctionPass {
     bool runOnFunction(Function &F);
 
     virtual void getAnalysisUsage(AnalysisUsage &AU) const {
@@ -31,15 +31,15 @@
     }
   };
 
-  RegisterOpt<ConstantPropogation> X("constprop","Simple constant propogation");
+  RegisterOpt<ConstantPropagation> X("constprop","Simple constant propagation");
 }
 
-Pass *createConstantPropogationPass() {
-  return new ConstantPropogation();
+Pass *createConstantPropagationPass() {
+  return new ConstantPropagation();
 }
 
 
-bool ConstantPropogation::runOnFunction(Function &F) {
+bool ConstantPropagation::runOnFunction(Function &F) {
   // Initialize the worklist to all of the instructions ready to process...
   std::set<Instruction*> WorkList(inst_begin(F), inst_end(F));
   bool Changed = false;
@@ -51,7 +51,7 @@
     if (!I->use_empty())                 // Don't muck with dead instructions...
       if (Constant *C = ConstantFoldInstruction(I)) {
         // Add all of the users of this instruction to the worklist, they might
-        // be constant propogatable now...
+        // be constant propagatable now...
         for (Value::use_iterator UI = I->use_begin(), UE = I->use_end();
              UI != UE; ++UI)
           WorkList.insert(cast<Instruction>(*UI));
@@ -1,6 +1,6 @@
-//===- ConstantProp.cpp - Code to perform Simple Constant Propogation -----===//
+//===- ConstantProp.cpp - Code to perform Simple Constant Propagation -----===//
 //
@@ -1,6 +1,6 @@
 //
-// This file implements constant propogation and merging:
+// This file implements constant propagation and merging:
 //
 // Specifically, this:

